home | help
uustat(1)		     General Commands Manual		       uustat(1)

NAME
     uustat - UUCP status inquiry and control

SYNOPSIS
     uustat -a

     uustat --all

     uustat [ -eKRiMNQ ] [ -sS system ] [ -uU user ] [ -cC command ] [ -oy hours
     ]	[  -B  lines  ]  [  --executions ] [ --kill-all ] [ --rejuvenate-all ] [
     --prompt ] [ --mail ] [ --notify ] [ --no-list ]  [  --system  system  ]  [
     --not-system  system ] [ --user user ] [ --not-user user ] [ --command com-
     mand ] [ --not-command command ] [ --older-than hours  ]  [  --younger-than
     hours ] [ --mail-lines lines ]

     uustat [ -kr jobid ] [ --kill jobid ] [ --rejuvenate jobid ]

     uustat  -q  [ -sS system ] [ -oy hours ] [ --system system ] [ --not-system
     system ] [ --older-than hours ] [ --younger-than hours ]

     uustat --list [ -sS system ] [ -oy hours ] [ --system system ] [ --not-sys-
     tem system ] [ --older-than hours ] [ --younger-than hours ]

     uustat -m

     uustat --status

     uustat -p

     uustat --ps

DESCRIPTION
     The uustat command can display various types of  status  information  about
     the UUCP system.  It can also be used to cancel or rejuvenate requests made
     by uucp (1) or uux (1).

     By  default uustat displays all jobs queued up for the invoking user, as if
     given the --user option with the appropriate argument.

     If any of the -a, --all, -e, --executions, -s, --system, -S,  --not-system,
     -u,  --user, -U, --not-user, -c, --command, -C, --not-command, -o, --older-
     than, -y, --younger-than options are given, then all jobs which  match  the
     combined specifications are displayed.

     The  -K  or  --kill-all  option may be used to kill off a selected group of
     jobs, such as all jobs more than 7 days old.

OPTIONS
     The following options may be given to uustat.

     -a, --all
	  List all queued file transfer requests.

     -e, --executions
	  List queued execution requests rather than queued  file  transfer  re-
	  quests.   Queued  execution requests are processed by uuxqt (8) rather
	  than uucico (8).  Queued execution requests may be  waiting  for  some
	  file	to  be transferred from a remote system.  They are created by an
	  invocation of uux (1).

     -s system, --system system
	  List all jobs queued up for the named system.  These	options  may  be
	  specified  multiple  times, in which case all jobs for all the systems
	  will be listed.  If used with --list only the systems  named	will  be
	  listed.

     -S system, --not-system system
	  List	all jobs queued for systems other than the one named.  These op-
	  tions may be specified multiple times, in which case no jobs from  any
	  of the specified systems will be listed.  If used with --list only the
	  systems  not named will be listed.  These options may not be used with
	  -s or --system.

     -u user, --user user
	  List all jobs queued up for the named  user.	 These	options  may  be
	  specified  multiple  times,  in  which case all jobs for all the users
	  will be listed.

     -U user, --not-user user
	  List all jobs queued up for users other than the one named.  These op-
	  tions may be specified multiple times, in which case no jobs from  any
	  of  the specified users will be listed.  These options may not be used
	  with -u or --user.

     -c command, --command command
	  List all jobs requesting the execution of the named command.	If  com-
	  mand	is  ALL this will list all jobs requesting the execution of some
	  command (as opposed to simply requesting a file transfer).  These  op-
	  tions may be specified multiple times, in which case all jobs request-
	  ing any of the commands will be listed.

     -C command, --not-command command
	  List	all  jobs  requesting  execution  of some command other than the
	  named command, or, if command is ALL, list all jobs  that  simply  re-
	  quest  a file transfer (as opposed to requesting the execution of some
	  command).  These options may be specified  multiple  times,  in  which
	  case	no  job requesting one of the specified commands will be listed.
	  These options may not be used with -c or --command.

     -o hours, --older-than hours
	  List all queued jobs older than the given number of  hours.	If  used
	  with --list only systems whose oldest job is older than the given num-
	  ber of hours will be listed.

     -y hours, --younger-than hours
	  List	all queued jobs younger than the given number of hours.  If used
	  with --list only systems whose oldest job is younger	than  the  given
	  number of hours will be listed.

     -k jobid, --kill jobid
	  Kill the named job.  The job id is shown by the default output format,
	  as  well as by the -j or --jobid option to uucp (1) or uux (1).  A job
	  may only be killed by the user who created the job, or by the UUCP ad-
	  ministrator or the superuser.  The -k or --kill options  may	be  used
	  multiple times on the command line to kill several jobs.

     -r jobid, --rejuvenate jobid
	  Rejuvenate the named job.  This will mark it as having been invoked at
	  the current time, affecting the output of the -o, --older-than, -y, or
	  --younger-than  options  and	preserving it from any automated cleanup
	  daemon.  The job id is shown by the default output format, as well  as
	  by  the  -j or --jobid options to uucp (1) or uux (1).  A job may only
	  be rejuvenated by the user who created the job, or by the UUCP  admin-
	  istrator or the superuser.  The -r or --rejuvenate options may be used
	  multiple times on the command line to rejuvenate several jobs.

     -q, --list
	  Display  the	status of commands, executions and conversations for all
	  remote systems for which commands or executions are queued.	The  -s,
	  --system,  -S,  --not-system, -o, --older-than, -y, and --younger-than
	  options may be used to restrict the systems which are listed.  Systems
	  for which no commands or executions are queued will never be listed.

     -m, --status
	  Display the status of conversations for all remote systems.

     -p, --ps
	  Display the status of all processes holding UUCP locks on  systems  or
	  ports.

     -i, --prompt
	  For  each  listed  job, prompt whether to kill the job or not.  If the
	  first character of the input line is y or Y the job will be killed.

     -K, --kill-all
	  Automatically kill each listed job.  This can be useful for  automatic
	  cleanup scripts, in conjunction with the --mail and --notify options.

     -R, --rejuvenate-all
	  Automatically  rejuvenate  each listed job.  This may not be used with
	  --kill-all.

     -M, --mail
	  For each listed job, send mail to the UUCP administrator.  If the  job
	  is killed (due to --kill-all or --prompt with an affirmative response)
	  the mail will indicate that.	A comment specified by the --comment op-
	  tion may be included.  If the job is an execution, the initial portion
	  of its standard input will be included in the mail message; the number
	  of  lines  to include may be set with the --mail-lines option (the de-
	  fault is 100).  If the standard input contains null characters, it  is
	  assumed to be a binary file and is not included.

     -N, --notify
	  For each listed job, send mail to the user who requested the job.  The
	  mail is identical to that sent by the -M or --mail options.

     -W comment, --comment comment
	  Specify a comment to be included in mail sent with the -M, --mail, -N,
	  or --notify options.

     -B lines, --mail-lines lines
	  When	the  -M,  --mail,  -N, or --notify options are used to send mail
	  about an execution with standard input, this option controls the  num-
	  ber of lines of standard input to include in the message.  The default
	  is 100.

     -Q, --no-list
	  Do  not  actually list the job, but only take any actions indicated by
	  the -i, --prompt, -K, --kill-all, -M, --mail, -N or --notify options.

     -x type, --debug type
	  Turn on particular debugging types.  The following  types  are  recog-
	  nized:  abnormal,  chat,  handshake,	uucp-proto, proto, port, config,
	  spooldir,  execute,  incoming,  outgoing.   Only   abnormal,	 config,
	  spooldir and execute are meaningful for uustat.

	  Multiple  types may be given, separated by commas, and the --debug op-
	  tion may appear multiple times.  A number may  also  be  given,  which
	  will	turn  on  that	many types from the foregoing list; for example,
	  --debug 2 is equivalent to --debug abnormal,chat.

     -I file, --config file
	  Set configuration file to use.  This option may not be available,  de-
	  pending upon how uustat was compiled.

     -v, --version
	  Report version information and exit.

     --help
	  Print a help message and exit.

EXAMPLES
     uustat --all
     Display status of all jobs.  A sample output line is as follows:
	  bugsA027h bugs ian 04-01 13:50 Executing rmail ian@airs.com (sending 1283 bytes)
     The format is
	  jobid system user queue-date command (size)
     The  jobid  may  be passed to the --kill or --rejuvenate options.	The size
     indicates how much data is to be transferred to the remote system,  and  is
     absent  for  a  file  receive request.  The --system, --not-system, --user,
     --not-user, --command, --not-command, --older-than, and --younger-than  op-
     tions may be used to control which jobs are listed.

     uustat --executions
     Display status of queued up execution requests.  A sample output line is as
     follows:
	  bugs bugs!ian 05-20 12:51 rmail ian
     The format is
	  system requestor queue-date command
     The  --system,  --not-system, --user, --not-user, --command, --not-command,
     --older-than, and --younger-than options may be used to control  which  re-
     quests are listed.

     uustat --list
     Display  status  for  all systems with queued up commands.  A sample output
     line is as follows:
	  bugs		  4C (1 hour)	0X (0 secs) 04-01 14:45 Dial failed
     This indicates the system, the number of queued commands, the  age  of  the
     oldest  queued  command,  the number of queued local executions, the age of
     the oldest queued execution, the date of the  last  conversation,	and  the
     status of that conversation.

     uustat --status
     Display  conversation  status for all remote systems.  A sample output line
     is as follows:
	  bugs		 04-01 15:51 Conversation complete
     This indicates the system, the date of the last conversation, and the  sta-
     tus of that conversation.	If the last conversation failed, uustat will in-
     dicate  how  many attempts have been made to call the system.  If the retry
     period is currently preventing calls to that system, uustat  also	displays
     the time when the next call will be permitted.

     uustat --ps
     Display  the status of all processes holding UUCP locks.  The output format
     is system dependent, as uustat simply invokes ps (1) on each process  hold-
     ing a lock.

	  uustat --command rmail --older-than 168 --kill-all --no-list --mail --notify --comment "Queued for over 1 week"
     This  will kill all rmail commands that have been queued up waiting for de-
     livery for over 1 week (168 hours).  For each such command,  mail	will  be
     sent both to the UUCP administrator and to the user who requested the rmail
     execution.   The  mail  message  sent  will include the string given by the
     --comment option.	The --no-list option prevents any of the jobs from being
     listed on the terminal, so any output from the program will be  error  mes-
     sages.

SEE ALSO
     ps(1), rmail(8), uucp(1), uux(1), uucico(8), uuxqt(8)

AUTHOR
     Ian Lance Taylor (ian@airs.com)

				Taylor UUCP 1.07		       uustat(1)

home | help